@@ -87,7 +87,7 @@ int main(int argc, char **argv)
 
     DaemonDbusInterface iface;
 
-    auto refreshMenu = [&iface, &model, &menu, &helper, &dialog]() {
+    auto refreshMenu = [&iface, &model, &menu, &dialog]() {
         menu->clear();
         auto configure = menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure..."));
         QObject::connect(configure, &QAction::triggered, configure, [&dialog]() {
@@ -139,7 +139,7 @@ int main(int argc, char **argv)
 #endif
     };
 
-    QObject::connect(&iface, &DaemonDbusInterface::pairingRequestsChangedProxy, &model, refreshMenu);
+    QObject::connect(&iface, &DaemonDbusInterface::pairingRequestsChanged, &model, refreshMenu);
     QObject::connect(&model, &DevicesModel::rowsInserted, &model, refreshMenu);
     QObject::connect(&model, &DevicesModel::rowsRemoved, &model, refreshMenu);
 
